property spriteNum, myCursorType, myBuiltInCursor, myCursorMember, myCustomCursor, myCustomMask, mySprite, mySavedCursor, pEnabled, pCursorMethod, pRollover, pSwitchCursor

on beginSprite me
  mySprite = sprite(me.spriteNum)
  if pCursorMethod = #sprite then
    mySavedCursor = mySprite.cursor
  end if
  pRollover = 0
  pSwitchCursor = 0
  if voidp(pEnabled) then
    pEnabled = 1
  end if
  if pEnabled then
    if pCursorMethod = #sprite then
      SetSpriteCursor(me)
    else
      if rollover(me.spriteNum) then
        SetSpriteCursor(me)
      end if
    end if
  end if
end

on endSprite me
  me.RevertSpriteCursor()
end

on Cursor_EnableChange me, bEnable
  pEnabled = bEnable
  if pEnabled then
    if pCursorMethod = #sprite then
      SetSpriteCursor(me)
    else
      if rollover(me.spriteNum) then
        SetSpriteCursor(me)
      end if
    end if
  else
    RevertSpriteCursor(me)
  end if
end

on mouseEnter me
  if pCursorMethod = #movie then
    SetSpriteCursor(me)
  end if
end

on mouseLeave me
  if pCursorMethod = #movie then
    RevertSpriteCursor(me)
  end if
end

on RevertSpriteCursor me
  if pCursorMethod = #movie then
    cursor(-1)
  else
    if not voidp(mySavedCursor) then
      sprite(me.spriteNum).cursor = mySavedCursor
    end if
  end if
end

on SetSpriteCursor me
  if pEnabled then
    mySprite = sprite(me.spriteNum)
    if voidp(myCursorType) then
      mySprite.cursor = myBuiltInCursor
      exit
    end if
    case myCursorType of
      "Built-in cursor":
        if pCursorMethod = #movie then
          cursor(myBuiltInCursor)
        else
          mySprite.cursor = myBuiltInCursor
        end if
      "Cursor Member":
        myCursorMember = value(myCursorMember)
        cursorList = [myCursorMember.number]
        if pCursorMethod = #movie then
          cursor(cursorList)
        else
          mySprite.cursor = cursorList
        end if
      "1 bit bitmap":
        myCustomCursorVal = value(member(myCustomCursor, "JNBehavior"))
        cursorList = [myCustomCursorVal]
        if myCustomMask <> "no mask" then
          myCustomMaskVal = value(member(myCustomMask, "JNBehavior"))
          cursorList.append(myCustomMaskVal)
        end if
        if pCursorMethod = #movie then
          cursor(cursorList)
        else
          mySprite.cursor = cursorList
        end if
    end case
  end if
end

on isOKToAttach me, aSpriteType, aSpriteNum
  case aSpriteType of
    #graphic:
      return 1
    #script:
      return 0
  end case
end

on getPropertyDescriptionList me
  if not (the currentSpriteNum) then
    exit
  end if
  propertyDescriptionList = [:]
  propertyDescriptionList.addProp(#pCursorMethod, [#comment: "Cursor Change Method:", #format: #symbol, #range: [#sprite, #movie], #default: #sprite])
  cursorTypes = []
  cursorMembersList = GetSuitableMembers([#cursor])
  cursorBitmapsList = GetCursorBitmaps(me)
  cursorMasksList = duplicate(cursorBitmapsList)
  cursorMasksList.addAt(1, "no mask")
  cursorMembers = cursorMembersList.count()
  bitmapCursors = cursorBitmapsList.count()
  if cursorMembers then
    cursorTypes.append("Cursor Member")
  end if
  if bitmapCursors then
    cursorTypes.append("1 bit bitmap")
  end if
  if cursorTypes.count() then
    cursorTypes.addAt(2, "Built-in cursor")
    propertyDescriptionList.addProp(#myCursorType, [#comment: "CHOICE OF TYPE - Use which type of cursor?", #format: #string, #range: cursorTypes, #default: cursorTypes[1]])
    propertyDescriptionList.addProp(#myBuiltInCursor, [#comment: "CHOICE OF CURSOR   -               Built-in cursor:", #format: #cursor, #default: 280])
  else
    return [#myBuiltInCursor: [#comment: "Use which cursor?", #format: #cursor, #default: 280]]
  end if
  if cursorMembers then
    propertyDescriptionList.addProp(#myCursorMember, [#comment: "-             Cursor member:", #format: #member, #range: cursorMembersList, #default: cursorMembersList[1]])
  end if
  if bitmapCursors then
    if the number of member "pointerHand" > 0 then
      cursHandDef = member("pointerHand")
    else
      cursHandDef = 0
    end if
    if the number of member "pointerHand.mask" > 0 then
      maskHandDef = member("pointerHand.mask")
    else
      maskHandDef = 0
    end if
    propertyDescriptionList.addProp(#myCustomCursor, [#comment: "-   1 bit bitmap (image)", #format: #bitmap, #range: cursorBitmapsList, #default: cursHandDef])
    propertyDescriptionList.addProp(#myCustomMask, [#comment: "1 bit bitmap   (mask)", #format: #bitmap, #range: cursorMasksList, #default: maskHandDef])
  end if
  return propertyDescriptionList
end

on GetCursorBitmaps me
  cursorBitmapsList = []
  maxCastLib = the number of castLibs
  repeat with theCastLib = 1 to maxCastLib
    maxMember = the number of castMembers of castLib theCastLib
    repeat with memberNumber = 1 to maxMember
      theMember = member(memberNumber, theCastLib)
      if theMember.type = #bitmap then
        if theMember.depth > 1 then
          next repeat
        end if
        if theMember.width > 20 then
          next repeat
        end if
        if theMember.height > 20 then
          next repeat
        end if
        if theMember.name = EMPTY then
          cursorBitmapsList.append(theMember)
          next repeat
        end if
        cursorBitmapsList.append(theMember.name)
      end if
    end repeat
  end repeat
  return cursorBitmapsList
end

on getBehaviorDescription me
  return getDescriptionText(me)
end

on getBehaviorTooltip me
  return "Use with graphic members." & RETURN & RETURN & "Modifies the cursor when the mouse rolls over a sprite." & RETURN & RETURN & "You can use built-in or custom images for the cursor."
end
